.. _recipe_asr.hse:

asr.hse
=======


.. contents:: Contents
   :local:

Summary
-------

This is the documentation for :py:mod:`asr.hse`-recipe.
This recipe is comprised of 2 steps, namely:

  - :py:func:`asr.hse.calculate`
  - :py:func:`asr.hse.main`

Run this recipe through the CLI interface

.. code-block:: console

   $ asr run asr.hse

or as a python module

.. code-block:: console

   $ python -m asr.hse

Detailed description
--------------------
HSE band structure.

Steps
-----


asr.hse@calculate
^^^^^^^^^^^^^^^^^
.. autofunction:: asr.hse.calculate
   

asr.hse
^^^^^^^
.. autofunction:: asr.hse.main
   